@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Mugshot - Lightweight user configuration utility
-#   Copyright (C) 2013-2015 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2013-2018 Sean Davis <smd.seandavis@gmail.com>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License as published by
@@ -18,18 +18,16 @@
 
 from locale import gettext as _
 
-import os
-# Used for automating chfn
-import pexpect
-# Used for copying files to ~/.face
-import shutil
-# Used for which command and checking for running processes.
-import subprocess
-# DBUS interface is used to update pidgin buddyicon when pidgin is running.
-import dbus
-
-from gi.repository import Gtk, GdkPixbuf, GLib, Gio  # pylint: disable=E0611
 import logging
+import os
+import shutil
+import subprocess
+
+import dbus
+import pexpect
+
+from gi.repository import Gtk, GdkPixbuf, GLib  # pylint: disable=E0611
+
 
 from mugshot_lib import Window, SudoDialog, AccountsServiceAdapter, helpers
 
@@ -101,7 +99,7 @@ def has_gstreamer_camerasrc_support():
 def has_camera_libraries():
     """Return True if it is possible to display the camera dialog."""
     try:
-        from gi.repository import Cheese, Clutter, GtkClutter
+        from gi.repository import Cheese, Clutter, GtkClutter  # pylint: disable=W0612
     except:
         return False
     return True
@@ -257,9 +255,12 @@ class MugshotWindow(Window):
             logger.debug('Found profile image: %s' % str(image))
 
             if os.path.isfile(face):
-                if os.path.samefile(image, face):
-                    self.updated_image = face
-                else:
+                try:
+                    if os.path.samefile(image, face):
+                        self.updated_image = face
+                    else:
+                        self.updated_image = None
+                except FileNotFoundError:
                     self.updated_image = None
                 self.set_user_image(face)
             elif os.path.isfile(image):
@@ -304,7 +305,7 @@ class MugshotWindow(Window):
                 self.menuitem1.set_visible(True)
                 self.image_remove.set_visible(True)
                 return
-            except GLib.Error:
+            except GLib.Error:  # pylint: disable=E0712
                 pass
 
         self.user_image.set_from_icon_name('avatar-default', 128)
@@ -506,6 +507,7 @@ class MugshotWindow(Window):
             return True
         if self.email != self.email_entry.get_text().strip():
             return True
+        return False
 
     def save_as_details(self):
         if not self.accounts_service.available():
@@ -535,15 +537,14 @@ class MugshotWindow(Window):
         if modified:
             logger.debug('chfn details have been modified.')
             return True
-        else:
-            logger.debug('chfn details have NOT been modified.')
-            return False
+        logger.debug('chfn details have NOT been modified.')
+        return False
 
     def process_terminal_password(self, command, password):
         """Handle password prompts from the interactive chfn commands."""
         # Force the C language for guaranteed english strings in the script.
         logger.debug('Executing: %s' % command)
-        child = SudoDialog.env_spawn(command, 5)
+        child = SudoDialog.env_spawn(command, [], 5)
         child.write_to_stdout = True
         try:
             child.expect([".*ssword.*", pexpect.EOF])
@@ -612,8 +613,15 @@ class MugshotWindow(Window):
             success = False
 
         logger.debug('Updating Office Phone...')
-        command = "%s -w \"%s\" %s" % (chfn, office_phone, username)
-        if self.process_terminal_password(command, password):
+
+        # chfn 2.29 uses "-p" as parameter for changing the office-phone (LP: #1699285)
+        p_command = "%s -p \"%s\" %s" % (chfn, office_phone, username)
+
+        # other (newer, older?) use "-w"
+        w_command = "%s -w \"%s\" %s" % (chfn, office_phone, username)
+
+        if self.process_terminal_password(p_command, password) or \
+                self.process_terminal_password(w_command, password):
             self.office_phone = office_phone
         else:
             success = False
@@ -675,7 +683,7 @@ class MugshotWindow(Window):
                     data[key] = dataset[key]
 
         # Then get data from dconf
-        if len(self.settings['initials']) > len(data['initials']):
+        if len(self.settings['initials']) > 0:
             data['initials'] = self.settings['initials']
         if len(data['email']) == 0:
             data['email'] = self.settings['email']
@@ -706,8 +714,15 @@ class MugshotWindow(Window):
             return None
 
         name = self.accounts_service.get_real_name()
-        name = self.split_name(name)
+        if name:
+            name = self.split_name(name)
+        else:
+            name = {'first': '', 'last': '', 'initials': ''}
+
         email = self.accounts_service.get_email()
+        if not email:
+            email = ''
+
         data = {'first_name': name['first'], 'last_name': name['last'],
                 'home_phone': '', 'office_phone': '',
                 'initials': name['initials'], 'email': email, 'fax': ''}
@@ -719,6 +734,7 @@ class MugshotWindow(Window):
         data = {'first_name': name['first'], 'last_name': name['last'],
                 'home_phone': '', 'office_phone': '',
                 'initials': name['initials'], 'email': '', 'fax': ''}
+        return data
 
     def get_passwd_data(self):
         """Get user details from passwd"""
@@ -735,14 +751,15 @@ class MugshotWindow(Window):
                 details.append("")
 
             # Extract the user details
-            name, office, office_phone, home_phone = details[:4]
+            name = details[0]
+            office_phone = details[2]
+            home_phone = details[3]
         except subprocess.CalledProcessError:
             logger.warning("User %s not found in /etc/passwd. "
                            "Mugshot may not function correctly." % username)
-            office = ""
+            name = ""
             office_phone = ""
             home_phone = ""
-            name = ""
 
         name = self.split_name(name)
 
